==> haskell-hpack-0.38.0-13-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.38.0
visibility:           public
id:                   hpack-0.38.0-KzucHDb4C1kBfakJLfPcEB
key:                  hpack-0.38.0-KzucHDb4C1kBfakJLfPcEB
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  6295437cb7e5cd93be455da648cefa95
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.38.0-KzucHDb4C1kBfakJLfPcEB
depends:
    Cabal-3.10.3.0 Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-client-tls-0.3.6.4-GXwyMNGv8mPI3u8Rlj5noc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    infer-license-0.2.0-6EhbsJpqErpF3cp3c1gxOw mtl-2.3.1 pretty-1.1.3.6
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.38.0-16-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.38.0
visibility:           public
id:                   hpack-0.38.0-DLGZwhkHMPv3jPvvHnS7OB
key:                  hpack-0.38.0-DLGZwhkHMPv3jPvvHnS7OB
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  7dae3d3c7f4b1ce97f5e98d42b654ac3
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hpack-0.38.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.38.0-DLGZwhkHMPv3jPvvHnS7OB
depends:
    Cabal-3.10.3.0 Glob-0.10.2-FFUARUINQX9K4f2r91vRK8
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH base-4.18.2.1
    bifunctors-5.6.2-I7pgRA67vmLKXPFLDlBNmR bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    http-client-0.7.19-HYRPxJ1velFCbteX9ut4f6
    http-client-tls-0.3.6.4-ILttD7UGaFL2zbr7B8I43g
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    infer-license-0.2.0-1AzD4kYmhia4kHPfqjwuvO mtl-2.3.1 pretty-1.1.3.6
    scientific-0.3.8.0-E8K90IhCZpR98POp8HwlML text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O
    vector-0.13.2.0-DULMVARQ1CU3TLBOg9xkS6
    yaml-0.11.11.2-7sI7sa5XZN9728orpxXF0B

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
